(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "./utils"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require("./utils");
    const axisReducer = ({ result, posValue }, value) => ({
        result: result + posValue * (value === -1 ? 0 : value),
        posValue: posValue / 20
    });
    const decodeAxis = (axis) => axis.map(utils_1.digitToValue).reduce(axisReducer, { result: 0, posValue: 20 }).result;
    const resolution = (code) => {
        const length = code.replace(/[+0]/g, '').length / 2;
        return 20 / Math.pow(20, length - 1);
    };
    const decode = (code) => {
        if (!utils_1.isValidCode(code))
            return null;
        const res = resolution(code);
        const [lat, lon] = code
            .replace(/[+]/g, '')
            .split('')
            .reduce((arrs, digit, idx) => idx % 2 === 0 ? [arrs[0].concat(digit), arrs[1]] : [arrs[0], arrs[1].concat(digit)], [[], []])
            .map(decodeAxis)
            .map(axis => axis + res / 2);
        return {
            latitude: parseFloat((lat - 90).toFixed(6)),
            longitude: parseFloat((lon - 180).toFixed(6)),
            resolution: res
        };
    };
    exports.default = decode;
});
//# sourceMappingURL=decode.js.map