(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "./utils"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require("./utils");
    const digitReducer = ({ value, result, posValue }) => {
        const q = Math.floor(value / posValue);
        return {
            value: value - q * posValue,
            posValue: posValue / 20,
            result: [...result, utils_1.valueToDigit(q)]
        };
    };
    const encodeAxis = (length, value) => Array(length)
        .fill(undefined)
        .reduce(digitReducer, { value, posValue: 20, result: [] }).result;
    const interleave = (length) => (xs, ys) => {
        const digits = [].concat.apply([], xs.map((x, i) => [x, ys[i]]).concat(length > 8 ? [] : Array(8 - length).fill('0')));
        return digits
            .slice(0, 8)
            .concat('+')
            .concat(digits.slice(8))
            .join('');
    };
    const normalizeLatitude = (lat) => Math.min(180, Math.max(0, lat + 90));
    const normalizeLongitude = (lon) => (lon + 180) % 360;
    const encode = (coordinates, length = 10) => {
        if (length < 2 || length > 10 || length % 2 !== 0)
            return null;
        if (!utils_1.isValidCoordinates(coordinates))
            return null;
        const latitude = normalizeLatitude(utils_1.parseNum(coordinates.latitude));
        const longitude = normalizeLongitude(utils_1.parseNum(coordinates.longitude));
        return interleave(length)(encodeAxis(length / 2, latitude), encodeAxis(length / 2, longitude));
    };
    exports.default = encode;
});
//# sourceMappingURL=encode.js.map