(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "./utils"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const utils_1 = require("./utils");
    describe('isValidCoordinates', () => {
        it('should return null if the input is undefined', () => {
            expect(utils_1.isValidCoordinates(undefined)).toBe(false);
        });
        it('should return false if the input is not an object', () => {
            expect(utils_1.isValidCoordinates('foo')).toBe(false);
        });
        it("should return false if the input doesn't contain longitude and latitude", () => {
            expect(utils_1.isValidCoordinates({})).toBe(false);
            expect(utils_1.isValidCoordinates({ longitude: '' })).toBe(false);
            expect(utils_1.isValidCoordinates({ latitude: '' })).toBe(false);
        });
        it('should return true for valid coordinates', () => {
            const latitude = 59.332438;
            const longitude = 18.118813;
            expect(utils_1.isValidCoordinates({ latitude, longitude })).toBe(true);
        });
    });
    describe('isValidCode', () => {
        it('returns null for non-string input', () => {
            expect(utils_1.isValidCode(undefined)).toBe(false);
            expect(utils_1.isValidCode(42)).toBe(false);
            expect(utils_1.isValidCode({})).toBe(false);
        });
        it('returns null for invalid length', () => {
            expect(utils_1.isValidCode('')).toBe(false);
            expect(utils_1.isValidCode('23')).toBe(false);
            expect(utils_1.isValidCode('23456789CFGH')).toBe(false); // 12
        });
        it('returns null for invalid digits', () => {
            expect(utils_1.isValidCode('1AB')).toBe(false);
            expect(utils_1.isValidCode('9FFW84J9-XG')).toBe(false);
            expect(utils_1.isValidCode('  9FFW84J9+XG  ')).toBe(false);
        });
        it('isValidCodes the plus code', () => {
            expect(utils_1.isValidCode('9FFW84J9+XG')).toBe(true);
        });
    });
    describe('digitToValue', () => {
        it('converts digits to values', () => {
            expect(utils_1.digitToValue('2')).toEqual(0);
            expect(utils_1.digitToValue('9')).toEqual(7);
            expect(utils_1.digitToValue('F')).toEqual(9);
            expect(utils_1.digitToValue('W')).toEqual(18);
        });
    });
    describe('valueToDigit', () => {
        it('converts values to digits', () => {
            expect(utils_1.valueToDigit(0)).toEqual('2');
            expect(utils_1.valueToDigit(7)).toEqual('9');
            expect(utils_1.valueToDigit(9)).toEqual('F');
            expect(utils_1.valueToDigit(18)).toEqual('W');
        });
    });
    describe('parseNum', () => {
        it('passes through floats', () => {
            expect(utils_1.parseNum(1.5)).toBe(1.5);
        });
        it('parses strings', () => {
            expect(utils_1.parseNum('3.14')).toBe(3.14);
        });
    });
});
//# sourceMappingURL=utils.spec.js.map